##  Next Steps
After you have populated your workspace with sufficient data, you can start a systematic review of your organization's applications, evaluating their interdependencies, usage, and contribution to the business. Make sure to assess applications based on Business Criticality, Functional Fit, and Technical Fit. Use the [TIME](https://help.sap.com/docs/leanix/ea/time?locale=en-US&state=PRODUCTION&version=CLOUD) assessment and [6R](https://help.sap.com/docs/leanix/ea/6r?locale=en-US&state=PRODUCTION&version=CLOUD) frameworks for a comprehensive evaluation.
The accuracy of the analysis relies on the sufficiency of data quality. To enrich and refine your data, make use of the application and IT component data from the reference catalog. To learn more about using the reference catalog, see [Reference Catalog](https://help.sap.com/docs/leanix/ea/reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently.").
By identifying valuable and vulnerable applications, you can make efficient resource allocation and make informed decisions on further courses of action. In our [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") use case, you can learn more about how to get that 360° overview of your IT landscape and assess your application portfolio.
